@@ -52,7 +52,8 @@ SQLGetDiagRecImpl(SQLSMALLINT handle_type, SQLHANDLE handle,
                   SQLINTEGER *native_error, SQLCHAR *message,
                   SQLSMALLINT message_max, SQLSMALLINT *message_len);
 SQLRETURN SQL_API
-SQLPrepareImpl(SQLHSTMT hstmt, SQLCHAR *str, SQLINTEGER str_len);
+SQLPrepareImpl(SQLHSTMT hstmt, SQLCHAR *str, SQLINTEGER str_len,
+               bool force_prepare);
 
 SQLRETURN SQL_API
 SQLSetConnectAttrImpl(SQLHDBC hdbc, SQLINTEGER attribute,
@@ -212,7 +213,7 @@ SQLDescribeCol(SQLHSTMT hstmt, SQLUSMALLINT column,
 
   if (free_value == -1)
   {
-    set_mem_error(&stmt->dbc->mysql);
+    set_mem_error(stmt->dbc->mysql);
     return handle_connection_error(stmt);
   }
 
@@ -268,7 +269,7 @@ SQLDriverConnect(SQLHDBC hdbc, SQLHWND hwnd, SQLCHAR *in, SQLSMALLINT in_len,
     outw= (SQLWCHAR *)myodbc_malloc(sizeof(SQLWCHAR) * out_max, MYF(0));
     if (!outw)
     {
-      rc= set_dbc_error((DBC *)hdbc, "HY001", NULL, 0);
+      rc= ((DBC*)hdbc)->set_error("HY001", NULL, 0);
       goto error;
     }
   }
@@ -295,7 +296,7 @@ SQLDriverConnect(SQLHDBC hdbc, SQLHWND hwnd, SQLCHAR *in, SQLSMALLINT in_len,
     /* TODO what to do with errors? */
 
     if (*out_len > out_max - 1)
-      rc= set_dbc_error((DBC *)hdbc, "01004", NULL, 0);
+      rc= ((DBC*)hdbc)->set_error("01004", NULL, 0);
   }
 
 error:
@@ -343,7 +344,7 @@ SQLExecDirect(SQLHSTMT hstmt, SQLCHAR *str, SQLINTEGER str_len)
 
   CHECK_HANDLE(hstmt);
 
-  if ((error= SQLPrepareImpl(hstmt, str, str_len)))
+  if ((error= SQLPrepareImpl(hstmt, str, str_len, false)))
     return error;
   error= my_SQLExecute((STMT *)hstmt);
 
@@ -709,12 +710,13 @@ SQLPrepare(SQLHSTMT hstmt, SQLCHAR *str, SQLINTEGER str_len)
 {
   CHECK_HANDLE(hstmt);
 
-  return SQLPrepareImpl(hstmt, str, str_len);
+  return SQLPrepareImpl(hstmt, str, str_len, true);
 }
 
 
 SQLRETURN SQL_API
-SQLPrepareImpl(SQLHSTMT hstmt, SQLCHAR *str, SQLINTEGER str_len)
+SQLPrepareImpl(SQLHSTMT hstmt, SQLCHAR *str, SQLINTEGER str_len,
+               bool force_prepare)
 {
   STMT *stmt= (STMT *)hstmt;
 
@@ -723,7 +725,7 @@ SQLPrepareImpl(SQLHSTMT hstmt, SQLCHAR *str, SQLINTEGER str_len)
     we can pass it straight through. Otherwise it needs to be converted to
     the connection character set (probably utf-8).
   */
-  return MySQLPrepare(hstmt, str, str_len, false, false);
+  return MySQLPrepare(hstmt, str, str_len, false, false, force_prepare);
 }
 
 
@@ -953,8 +955,8 @@ SQLSetDescField(SQLHDESC hdesc, SQLSMALLINT record, SQLSMALLINT field,
                 SQLPOINTER value, SQLINTEGER value_len)
 {
   CHECK_HANDLE(hdesc);
-
-  return MySQLSetDescField(hdesc, record, field, value, value_len);
+  DESC *desc = (DESC*)hdesc;
+  return desc->set_field(record, field, value, value_len);
 }
 
 
