@@ -54,6 +54,42 @@ enum myodbcProcColumns {mypcPROCEDURE_CAT= 0, mypcPROCEDURE_SCHEM,  mypcPROCEDUR
                   /*15*/mypcSQL_DATETIME_SUB, mypcCHAR_OCTET_LENGTH,mypcORDINAL_POSITION,
                   /*18*/mypcIS_NULLABLE };
 
+/* SQLColumns */
+
+static char SC_type[10],SC_typename[20],SC_precision[10],SC_length[10],SC_scale[10],
+SC_nullable[10], SC_coldef[10], SC_sqltype[10],SC_octlen[10],
+SC_pos[10],SC_isnull[10];
+
+static char *SQLCOLUMNS_values[]= {
+    "","",NullS,NullS,SC_type,SC_typename,
+    SC_precision,
+    SC_length,SC_scale,"10",SC_nullable,"MySQL column",
+    SC_coldef,SC_sqltype,NullS,SC_octlen,NullS,SC_isnull
+};
+
+static MYSQL_FIELD SQLCOLUMNS_fields[]=
+{
+  MYODBC_FIELD_NAME("TABLE_CAT", 0),
+  MYODBC_FIELD_NAME("TABLE_SCHEM", 0),
+  MYODBC_FIELD_NAME("TABLE_NAME", NOT_NULL_FLAG),
+  MYODBC_FIELD_NAME("COLUMN_NAME", NOT_NULL_FLAG),
+  MYODBC_FIELD_SHORT("DATA_TYPE", NOT_NULL_FLAG),
+  MYODBC_FIELD_STRING("TYPE_NAME", 20, NOT_NULL_FLAG),
+  MYODBC_FIELD_LONG("COLUMN_SIZE", 0),
+  MYODBC_FIELD_LONG("BUFFER_LENGTH", 0),
+  MYODBC_FIELD_SHORT("DECIMAL_DIGITS", 0),
+  MYODBC_FIELD_SHORT("NUM_PREC_RADIX", 0),
+  MYODBC_FIELD_SHORT("NULLABLE", NOT_NULL_FLAG),
+  MYODBC_FIELD_NAME("REMARKS", 0),
+  MYODBC_FIELD_NAME("COLUMN_DEF", 0),
+  MYODBC_FIELD_SHORT("SQL_DATA_TYPE", NOT_NULL_FLAG),
+  MYODBC_FIELD_SHORT("SQL_DATETIME_SUB", 0),
+  MYODBC_FIELD_LONG("CHAR_OCTET_LENGTH", 0),
+  MYODBC_FIELD_LONG("ORDINAL_POSITION", NOT_NULL_FLAG),
+  MYODBC_FIELD_STRING("IS_NULLABLE", 3, 0),
+};
+
+const uint SQLCOLUMNS_FIELDS= array_elements(SQLCOLUMNS_values);
 
 /* Some common(for i_s/no_i_s) helper functions */
 const char *my_next_token(const char *prev_token,
@@ -67,7 +103,8 @@ create_empty_fake_resultset(STMT *stmt, MYSQL_ROW rowval, size_t rowsize,
 
 SQLRETURN
 create_fake_resultset(STMT *stmt, MYSQL_ROW rowval, size_t rowsize,
-                      my_ulonglong rowcnt, MYSQL_FIELD *fields, uint fldcnt);
+                      my_ulonglong rowcnt, MYSQL_FIELD *fields, uint fldcnt,
+                      bool copy_rowval);
 
 my_bool server_has_i_s(DBC *dbc);
 
