@@ -171,47 +171,6 @@ static MYSQL_RES *server_list_dbkeys(STMT *stmt,
 }
 
 
-/*
-****************************************************************************
-SQLColumns
-****************************************************************************
-*/
-
-char SC_type[10],SC_typename[20],SC_precision[10],SC_length[10],SC_scale[10],
-SC_nullable[10], SC_coldef[10], SC_sqltype[10],SC_octlen[10],
-SC_pos[10],SC_isnull[10];
-
-char *SQLCOLUMNS_values[]= {
-    "","",NullS,NullS,SC_type,SC_typename,
-    SC_precision,
-    SC_length,SC_scale,"10",SC_nullable,"MySQL column",
-    SC_coldef,SC_sqltype,NullS,SC_octlen,NullS,SC_isnull
-};
-
-MYSQL_FIELD SQLCOLUMNS_fields[]=
-{
-  MYODBC_FIELD_NAME("TABLE_CAT", 0),
-  MYODBC_FIELD_NAME("TABLE_SCHEM", 0),
-  MYODBC_FIELD_NAME("TABLE_NAME", NOT_NULL_FLAG),
-  MYODBC_FIELD_NAME("COLUMN_NAME", NOT_NULL_FLAG),
-  MYODBC_FIELD_SHORT("DATA_TYPE", NOT_NULL_FLAG),
-  MYODBC_FIELD_STRING("TYPE_NAME", 20, NOT_NULL_FLAG),
-  MYODBC_FIELD_LONG("COLUMN_SIZE", 0),
-  MYODBC_FIELD_LONG("BUFFER_LENGTH", 0),
-  MYODBC_FIELD_SHORT("DECIMAL_DIGITS", 0),
-  MYODBC_FIELD_SHORT("NUM_PREC_RADIX", 0),
-  MYODBC_FIELD_SHORT("NULLABLE", NOT_NULL_FLAG),
-  MYODBC_FIELD_NAME("REMARKS", 0),
-  MYODBC_FIELD_NAME("COLUMN_DEF", 0),
-  MYODBC_FIELD_SHORT("SQL_DATA_TYPE", NOT_NULL_FLAG),
-  MYODBC_FIELD_SHORT("SQL_DATETIME_SUB", 0),
-  MYODBC_FIELD_LONG("CHAR_OCTET_LENGTH", 0),
-  MYODBC_FIELD_LONG("ORDINAL_POSITION", NOT_NULL_FLAG),
-  MYODBC_FIELD_STRING("IS_NULLABLE", 3, 0),
-};
-
-const uint SQLCOLUMNS_FIELDS= array_elements(SQLCOLUMNS_values);
-
 /**
   Get the list of columns in a table matching a wildcard.
 
@@ -2359,7 +2318,8 @@ tables_no_i_s(SQLHSTMT hstmt,
                                     sizeof(SQLTABLES_type_values),
                                     sizeof(SQLTABLES_type_values) /
                                     sizeof(SQLTABLES_type_values[0]),
-                                    SQLTABLES_fields, SQLTABLES_FIELDS);
+                                    SQLTABLES_fields, SQLTABLES_FIELDS,
+                                    true);
         return rc;
       }
 
@@ -2388,7 +2348,8 @@ tables_no_i_s(SQLHSTMT hstmt,
       {
         rc = create_fake_resultset(stmt, SQLTABLES_owner_values,
                                    sizeof(SQLTABLES_owner_values),
-                                   1, SQLTABLES_fields, SQLTABLES_FIELDS);
+                                   1, SQLTABLES_fields, SQLTABLES_FIELDS,
+                                   true);
         return rc;
       }
 
