@@ -418,8 +418,6 @@ SQLRETURN DBC::connect(DataSource *dsrc)
     std::string tls_options;
 
     std::map<std::string, bool> opts = {
-      { "TLSv1", !dsrc->no_tls_1 },
-      { "TLSv1.1", !dsrc->no_tls_1_1 },
       { "TLSv1.2", !dsrc->no_tls_1_2 },
       { "TLSv1.3", !dsrc->no_tls_1_3 },
     };
@@ -436,6 +434,9 @@ SQLRETURN DBC::connect(DataSource *dsrc)
 
     if (tls_options.length())
       mysql_options(mysql, MYSQL_OPT_TLS_VERSION, tls_options.c_str());
+    else
+      return set_error("HY000",
+        "SSL connection error: No valid TLS version available", 0);
   }
 #endif
 
@@ -1340,3 +1341,28 @@ SQLRETURN SQL_API SQLDisconnect(SQLHDBC hdbc)
   return SQL_SUCCESS;
 }
 
+
+void DBC::execute_prep_stmt(MYSQL_STMT *pstmt, std::string &query,
+  MYSQL_BIND *param_bind, MYSQL_BIND *result_bind)
+{
+  if (
+    mysql_stmt_prepare(pstmt, query.c_str(), query.length()) ||
+    (param_bind && mysql_stmt_bind_param(pstmt, param_bind)) ||
+    mysql_stmt_execute(pstmt) ||
+    (result_bind && mysql_stmt_bind_result(pstmt, result_bind))
+  )
+  {
+    set_error("HY000");
+    throw error;
+  }
+
+  if (
+
+    (result_bind && mysql_stmt_store_result(pstmt))
+  )
+  {
+    set_error("HY000");
+    throw error;
+  }
+
+}
