@@ -611,7 +611,10 @@ struct DBC
   void add_desc(DESC* desc);
   void remove_desc(DESC *desc);
   SQLRETURN set_error(char *state, const char *message, uint errcode);
+  SQLRETURN set_error(char *state);
   SQLRETURN connect(DataSource *ds);
+  void execute_prep_stmt(MYSQL_STMT *pstmt, std::string &query,
+    MYSQL_BIND *param_bind, MYSQL_BIND *result_bind);
 
   inline bool transactions_supported()
   { return mysql->server_capabilities & CLIENT_TRANSACTIONS; }
@@ -781,6 +784,9 @@ struct xstring : public std::string
   xstring(T &&s) : Base(std::forward<T>(s))
   {}
 
+  xstring(SQLULEN v) : Base(std::to_string(v))
+  {}
+
   xstring(long long v) : Base(std::to_string(v))
   {}
 
@@ -793,6 +799,10 @@ struct xstring : public std::string
   xstring(int v) : Base(std::to_string(v))
   {}
 
+  xstring(unsigned int v) : Base(std::to_string(v))
+  {}
+
+
   const char *c_str() const { return m_is_null ? nullptr : Base::c_str(); }
   size_t size() const { return m_is_null ? 0 : Base::size(); }
 
@@ -900,6 +910,16 @@ struct ODBCEXCEPTION
 
 };
 
+struct ODBC_STMT
+{
+  MYSQL_STMT *m_stmt;
+
+  ODBC_STMT(MYSQL *mysql) { m_stmt = mysql_stmt_init(mysql); }
+  operator MYSQL_STMT*() { return m_stmt; }
+  ~ODBC_STMT() { mysql_stmt_close(m_stmt); }
+};
+
+
 struct STMT
 {
   DBC               *dbc;
@@ -924,13 +944,11 @@ struct STMT
   std::vector<MYSQL_BIND> query_attr_bind;
   std::vector<char*>      query_attr_names;
 
-  my_bool           lengths_allocated;
-  unsigned long     *lengths; /* used to set lengths if we shuffle field values
-                         of the resultset of auxiliary query or if we fix_fields. */
-                         /*
-                           We save a copy of the original query before we modify it for 'WHERE
-                           CURRENT OF' cursor handling.
-                         */
+  std::unique_ptr<my_bool[]> rb_is_null;
+  std::unique_ptr<my_bool[]> rb_err;
+  std::unique_ptr<unsigned long[]> rb_len;
+  std::unique_ptr<unsigned long[]> lengths;
+
   my_ulonglong      affected_rows;
   long              current_row;
   long              cursor_row;
@@ -1015,7 +1033,7 @@ struct STMT
     current_values(NULL), fields(NULL), end_of_set(NULL),
     tempbuf(),
     stmt_options(dbc->stmt_options),
-    param_bind(NULL), lengths_allocated(FALSE), lengths(NULL), affected_rows(0),
+    param_bind(NULL), lengths(nullptr), affected_rows(0),
     current_row(0), cursor_row(0), dae_type(0),
     order(NULL), order_count(0), param_count(0), current_param(0),
     rows_found_in_set(0),
