@@ -154,40 +154,6 @@ void myodbc_sqlstate3_init(void)
 }
 
 
-/*
-  @type    : myodbc3 internal
-  @purpose : sets the connection level errors, which doesn't need any
-  conversion
-*/
-
-SQLRETURN set_dbc_error(DBC *dbc, char *state,
-                        const char *message, uint errcode)
-{
-    myodbc_stpmov(dbc->error.sqlstate, state);
-    strxmov(dbc->error.message, MYODBC_ERROR_PREFIX, message, NullS);
-    dbc->error.native_error= errcode;
-    return SQL_ERROR;
-}
-
-
-/*
-  @type    : myodbc3 internal
-  @purpose : sets the statement level errors, which doesn't need any
-  conversion
-*/
-
-SQLRETURN myodbc_set_stmt_error( STMT       *  stmt,
-                          const char *  state,
-                          const char *  message,
-                          uint          errcode )
-{
-    myodbc_stpmov(stmt->error.sqlstate, state);
-    strxmov(stmt->error.message, stmt->dbc->st_error_prefix, message, NullS);
-    stmt->error.native_error = errcode;
-
-    return SQL_ERROR;
-}
-
 
 /*
   @type    : myodbc3 internal
@@ -258,6 +224,9 @@ void translate_error(char *save_state, myodbc_errid errid, uint mysql_err)
         case CR_CONNECTION_ERROR:
         case CR_SERVER_GONE_ERROR:
         case CR_SERVER_LOST:
+#if MYSQL_VERSION_ID > 80023
+        case ER_CLIENT_INTERACTION_TIMEOUT:
+#endif
             state= "08S01";
             break;
         case ER_MUST_CHANGE_PASSWORD_LOGIN:
@@ -323,7 +292,7 @@ SQLRETURN set_conn_error(DBC *dbc, myodbc_errid errid, const char *errtext,
 
 
 MYERROR::MYERROR(myodbc_errid errid, const char *errtext, SQLINTEGER errcode,
-                 char *prefix)
+                 const char *prefix)
 {
   SQLCHAR     *errmsg;
 
@@ -337,6 +306,15 @@ MYERROR::MYERROR(myodbc_errid errid, const char *errtext, SQLINTEGER errcode,
 }
 
 
+MYERROR::MYERROR(const char *state, const char *msg, SQLINTEGER errcode,
+                 const char *prefix)
+{
+  myodbc_stpmov(sqlstate, state);
+  strxmov(message, prefix, msg, NullS);
+  native_error = errcode;
+  retcode = SQL_ERROR;
+}
+
 
 /*
   @type    : myodbc3 internal
@@ -357,19 +335,22 @@ void set_mem_error(MYSQL *mysql)
 */
 SQLRETURN handle_connection_error(STMT *stmt)
 {
-  unsigned int err= mysql_errno(&stmt->dbc->mysql);
+  unsigned int err= mysql_errno(stmt->dbc->mysql);
   switch (err) {
   case 0:  /* no error */
     return SQL_SUCCESS;
   case CR_SERVER_GONE_ERROR:
   case CR_SERVER_LOST:
-    return set_stmt_error(stmt, "08S01", mysql_error(&stmt->dbc->mysql), err);
+#if MYSQL_VERSION_ID > 80023
+  case ER_CLIENT_INTERACTION_TIMEOUT:
+#endif
+    return stmt->set_error("08S01", mysql_error(stmt->dbc->mysql), err);
   case CR_OUT_OF_MEMORY:
-    return set_stmt_error(stmt, "HY001", mysql_error(&stmt->dbc->mysql), err);
+    return stmt->set_error("HY001", mysql_error(stmt->dbc->mysql), err);
   case CR_COMMANDS_OUT_OF_SYNC:
   case CR_UNKNOWN_ERROR:
   default:
-    return set_stmt_error(stmt, "HY000", mysql_error(&stmt->dbc->mysql), err);
+    return stmt->set_error("HY000", mysql_error(stmt->dbc->mysql), err);
   }
 }
 
@@ -380,7 +361,11 @@ SQLRETURN handle_connection_error(STMT *stmt)
 */
 my_bool is_connection_lost(uint errcode)
 {
-  if (errcode==CR_SERVER_GONE_ERROR || errcode==CR_SERVER_LOST)
+  if (errcode==CR_SERVER_GONE_ERROR || errcode==CR_SERVER_LOST
+#if MYSQL_VERSION_ID > 80023
+    || errcode==ER_CLIENT_INTERACTION_TIMEOUT
+#endif
+  )
   {
     return 1;
   }
