@@ -1,30 +1,24 @@
-// Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved. 
-// 
-// This program is free software; you can redistribute it and/or modify 
-// it under the terms of the GNU General Public License, version 2.0, as 
-// published by the Free Software Foundation. 
-// 
-// This program is also distributed with certain software (including 
-// but not limited to OpenSSL) that is licensed under separate terms, 
-// as designated in a particular file or component or in included license 
-// documentation. The authors of MySQL hereby grant you an 
-// additional permission to link the program and your derivative works 
-// with the separately licensed software that they have included with 
-// MySQL. 
-// 
-// Without limiting anything contained in the foregoing, this file, 
-// which is part of MySQL Server, is also subject to the 
-// Universal FOSS Exception, version 1.0, a copy of which can be found at 
-// http://oss.oracle.com/licenses/universal-foss-exception. 
-// 
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of 
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
-// See the GNU General Public License, version 2.0, for more details. 
-// 
-// You should have received a copy of the GNU General Public License 
-// along with this program; if not, write to the Free Software Foundation, Inc., 
-// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+/* Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License, version 2.0, for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */
 
 #ifndef _my_audit_h
 #define _my_audit_h
@@ -40,6 +34,7 @@
 #endif
 #include "my_command.h"
 #include "my_sqlcommand.h"
+#include "plugin_audit_message_types.h"
 
 #define MYSQL_AUDIT_INTERFACE_VERSION 0x0401
 
@@ -61,6 +56,7 @@ typedef enum {
   MYSQL_AUDIT_QUERY_CLASS = 9,
   MYSQL_AUDIT_STORED_PROGRAM_CLASS = 10,
   MYSQL_AUDIT_AUTHENTICATION_CLASS = 11,
+  MYSQL_AUDIT_MESSAGE_CLASS = 12,
   /* This item must be last in the list. */
   MYSQL_AUDIT_CLASS_MASK_SIZE
 } mysql_event_class_t;
@@ -611,4 +607,27 @@ struct mysql_event_authentication {
   bool is_role;
 };
 
+#define MYSQL_AUDIT_MESSAGE_ALL \
+  (MYSQL_AUDIT_MESSAGE_INTERNAL | MYSQL_AUDIT_MESSAGE_USER)
+
+/**
+  @struct mysql_event_message
+
+  Structure for MYSQL_AUDIT_MESSAGE_CLASS event class.
+*/
+struct mysql_event_message {
+  /** Event subclass. */
+  mysql_event_message_subclass_t event_subclass;
+  /** Component. */
+  MYSQL_LEX_CSTRING component;
+  /** Producer */
+  MYSQL_LEX_CSTRING producer;
+  /** Message */
+  MYSQL_LEX_CSTRING message;
+  /** Key value map pointer. */
+  mysql_event_message_key_value_t *key_value_map;
+  /** Key value map length. */
+  size_t key_value_map_length;
+};
+
 #endif
