@@ -274,13 +274,12 @@ DECLARE_TEST(charset_utf8)
   DECLARE_BASIC_HANDLES(henv1, hdbc1, hstmt1);
   SQLCHAR buff1[512], buff2[512];
   SQLLEN len;
-  SQLINTEGER str_size;
-
   /**
    Bug #19345: Table column length multiplies on size session character set
   */
   ok_sql(hstmt, "DROP TABLE IF EXISTS t_bug19345");
-  ok_sql(hstmt, "CREATE TABLE t_bug19345 (a VARCHAR(10), b VARBINARY(10))");
+  ok_sql(hstmt, "CREATE TABLE t_bug19345 (a VARCHAR(10), b VARBINARY(10)) "
+                "DEFAULT CHARSET = utf8mb4");
   ok_sql(hstmt, "INSERT INTO t_bug19345 VALUES ('abc','def')");
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
@@ -304,20 +303,9 @@ DECLARE_TEST(charset_utf8)
 
   ok_stmt(hstmt1, SQLFetch(hstmt1));
   is_num(my_fetch_int(hstmt1, 7), 10);
-  ok_stmt(hstmt1, SQLGetData(hstmt1, 8, SQL_C_LONG, &str_size, 0, NULL));
-  /* utf8 mbmaxlen = 3 in libmysql before MySQL 6.0 */
-  /*
-  if (str_size == 30)
-  {
-    is_num(my_fetch_int(hstmt1, 8), 30);
-    is_num(my_fetch_int(hstmt1, 16), 30);
-  }
-  else
-  {
-    is_num(my_fetch_int(hstmt1, 8), 40);
-    is_num(my_fetch_int(hstmt1, 16), 40);
-  }
-  */
+  is_num(my_fetch_int(hstmt1, 8), 40);
+  is_num(my_fetch_int(hstmt1, 16), 40);
+
   ok_stmt(hstmt1, SQLFetch(hstmt1));
   is_num(my_fetch_int(hstmt1, 7), 10);
   is_num(my_fetch_int(hstmt1, 8), 10);
@@ -1157,25 +1145,68 @@ DECLARE_TEST(t_tls_opts)
   SQLCHAR buf[1024] = { 0 };
   SQLLEN len = 0;
 
-  char *opts[] = {
-    "NO_TLS_1_0=1;",
-    "NO_TLS_1_1=1;",
-    "NO_TLS_1_2=1;",
-    "NO_TLS_1_3=1;"
-  };
+  ok_sql(hstmt, "SHOW VARIABLES LIKE 'tls_version'");
+  ok_stmt(hstmt, SQLFetch(hstmt));
+  my_fetch_str(hstmt, buf, 2);
+  printf("TLS Versions supported by the server: %s\n", buf);
+  is(SQL_NO_DATA == SQLFetch(hstmt));
 
-  char *vals[] = {
-    "TLSv1",
-    "TLSv1.1",
-    "TLSv1.2",
-    "TLSv1.3"
-  };
+#define VERSION_COUNT 2
 
-  for (int i = 0; i < 4; ++i)
+  // supported TLS versions, starting from the highest one.
+  // Tests below assume that ver[] covers all versions supported
+  // by both server and connector and ver[0] is the highest supported one.
+  //
+  // Note: this means that these tests will fail when tested against
+  // a server that supports a new version beyond ver[0].
+
+  char *ver[VERSION_COUNT] = { "TLSv1.3", "TLSv1.2" };
+
+  // Corresponding NO_TLS_X options
+
+  char *opts[VERSION_COUNT] = { "NO_TLS_1_3=1;", "NO_TLS_1_2=1;" };
+
+  // Info about versions actually supported by server
+
+  unsigned supported_versions = 0;
+
+  for (unsigned i = 0; i < VERSION_COUNT; ++i)
+    if (strstr(buf, ver[i]) != NULL)
+      supported_versions |= (1u << i);
+
+
+  // Test disabling each of supported versions, the last iteration is
+  // testing a scenario where nothing is disabled.
+
+  for (int i = 0; i < VERSION_COUNT+1; ++i)
   {
-    printf("TLS Parameters: %s\n", opts[i]);
-    is(OK == alloc_basic_handles_with_opt(&henv1, &hdbc1, &hstmt1, NULL,
-      NULL, NULL, NULL, opts[i]));
+    unsigned ver_bit = 1u << i;
+
+    // Skip testing NO_TLS_X options if server does not support any good TLS
+    // version - in this case only the last iteration is performed.
+
+    if (i < VERSION_COUNT && !supported_versions)
+      continue;
+
+    // Note: Empty SOCKET option forces use of TCP connection even for
+    // localhost
+
+    char connstr[512] = "SOCKET=;";
+    if (i < VERSION_COUNT)
+      strncat(connstr, opts[i], sizeof(connstr));
+    printf("Connection options: %s\n", connstr);
+
+    int ret = alloc_basic_handles_with_opt(&henv1, &hdbc1, &hstmt1, NULL,
+      NULL, NULL, NULL, connstr);
+
+    // We accept a failed connection only if server does not support any
+    // other versions except the one being disabled.
+
+    if (OK != ret)
+    {
+      is(0 == (supported_versions & ~ver_bit));
+      continue;
+    }
 
     /* Check the affected tows */
     ok_sql(hstmt1, "SHOW STATUS LIKE 'Ssl_version'");
@@ -1183,15 +1214,62 @@ DECLARE_TEST(t_tls_opts)
     ok_stmt(hstmt1, SQLGetData(hstmt1, 2, SQL_C_CHAR, buf, sizeof(buf), &len));
 
     printf("SSL Version: %s\n\n", buf);
-    /*
-      Set one NO_TLS_X option and the version applied must be
-      not the same as disabled by the option
-    */
-    is(strcmp(vals[i], buf) != 0);
+
+    // Note: Check that actual version does not equal the disabled one
+
+    if (i < VERSION_COUNT)
+    {
+      is(strcmp(buf, ver[i]) != 0);
+    }
+    else
+    {
+      /*
+        If no version was disabled, check that the highest available one
+        was selected.
+
+        But first check that server supports at lest one of the TLS
+        versions, bacause otherwise if connection was accepted then something
+        is wrong: either old server picked old TLS version that we do not
+        support or new server picked a new TLS version we are not aware of
+        and this test should be updated.
+      */
+
+      is(supported_versions);
+
+      int j = 0;
+
+      for (; j < VERSION_COUNT; ++j)
+        if (supported_versions & (1u << j))
+          break;
+
+      is(j < VERSION_COUNT);
+      is(strcmp(buf, ver[j]) == 0);
+    }
 
     free_basic_handles(&henv1, &hdbc1, &hstmt1);
   }
 
+
+  // Test disabling all supported TLS versions.
+
+  {
+    /*
+      Disabling all TLS versions should lead to error. This is true also for
+      old servers that do not support any of the versions in ver[]. However,
+      a new server that supports a version beyond ver[0] might accept the
+      connection and this test will fail. In that case we need to update the
+      test to cover the new TLS version.
+    */
+
+    char connstr[512] = "SOCKET=;";
+    for (int i = 0; i < VERSION_COUNT; ++i)
+      strncat(connstr, opts[i], sizeof(connstr));
+    printf("Connection options: %s\n", connstr);
+
+    is(FAIL == alloc_basic_handles_with_opt(&henv1, &hdbc1, &hstmt1, NULL,
+      NULL, NULL, NULL, connstr));
+  }
+
   return OK;
 }
 
