@@ -36,7 +36,8 @@
 #include "stringutil.h"
 
 
-CHARSET_INFO *utf8_charset_info= NULL;
+CHARSET_INFO *utf8_charset_info = NULL;
+CHARSET_INFO *utf16_charset_info = NULL;
 
 
 /**
@@ -748,15 +749,339 @@ SQLWCHAR *sqlwcharncpy(SQLWCHAR *dest, const SQLWCHAR *src, size_t n)
 char * myodbc_strlwr(char *target, size_t len)
 {
   unsigned char *c= (unsigned char *)target;
-  if (len <= 0)
-    len= strlen(target);
+  if (-1 == len)
+    len= (int)strlen(target);
 
   while (len-- > 0)
-    *c++= tolower(*c);
+  {
+    *c= tolower(*c);
+    ++c;
+  }
 
   return target;
 }
 
+struct CHARSET_COLLATION_INFO charset_collation_info[] = {
+  {0, "NONE", "NONE", 0},
+  {1, "big5", "big5_chinese_ci", 2},
+  {2, "latin2", "latin2_czech_cs", 1},
+  {3, "dec8", "dec8_swedish_ci", 1},
+  {4, "cp850", "cp850_general_ci", 1},
+  {5, "latin1", "latin1_german1_ci", 1},
+  {6, "hp8", "hp8_english_ci", 1},
+  {7, "koi8r", "koi8r_general_ci", 1},
+  {8, "latin1", "latin1_swedish_ci", 1},
+  {9, "latin2", "latin2_general_ci", 1},
+  {10, "swe7", "swe7_swedish_ci", 1},
+  {11, "ascii", "ascii_general_ci", 1},
+  {12, "ujis", "ujis_japanese_ci", 3},
+  {13, "sjis", "sjis_japanese_ci", 2},
+  {14, "cp1251", "cp1251_bulgarian_ci", 1},
+  {15, "latin1", "latin1_danish_ci", 1},
+  {16, "hebrew", "hebrew_general_ci", 1},
+  {17, "NONE", "NONE", 0},
+  {18, "tis620", "tis620_thai_ci", 1},
+  {19, "euckr", "euckr_korean_ci", 2},
+  {20, "latin7", "latin7_estonian_cs", 1},
+  {21, "latin2", "latin2_hungarian_ci", 1},
+  {22, "koi8u", "koi8u_general_ci", 1},
+  {23, "cp1251", "cp1251_ukrainian_ci", 1},
+  {24, "gb2312", "gb2312_chinese_ci", 2},
+  {25, "greek", "greek_general_ci", 1},
+  {26, "cp1250", "cp1250_general_ci", 1},
+  {27, "latin2", "latin2_croatian_ci", 1},
+  {28, "gbk", "gbk_chinese_ci", 2},
+  {29, "cp1257", "cp1257_lithuanian_ci", 1},
+  {30, "latin5", "latin5_turkish_ci", 1},
+  {31, "latin1", "latin1_german2_ci", 1},
+  {32, "armscii8", "armscii8_general_ci", 1},
+  {33, "utf8", "utf8_general_ci", 3},
+  {34, "cp1250", "cp1250_czech_cs", 1},
+  {35, "ucs2", "ucs2_general_ci", 2},
+  {36, "cp866", "cp866_general_ci", 1},
+  {37, "keybcs2", "keybcs2_general_ci", 1},
+  {38, "macce", "macce_general_ci", 1},
+  {39, "macroman", "macroman_general_ci", 1},
+  {40, "cp852", "cp852_general_ci", 1},
+  {41, "latin7", "latin7_general_ci", 1},
+  {42, "latin7", "latin7_general_cs", 1},
+  {43, "macce", "macce_bin", 1},
+  {44, "cp1250", "cp1250_croatian_ci", 1},
+  {45, "utf8mb4", "utf8mb4_general_ci", 4},
+  {46, "utf8mb4", "utf8mb4_bin", 4},
+  {47, "latin1", "latin1_bin", 1},
+  {48, "latin1", "latin1_general_ci", 1},
+  {49, "latin1", "latin1_general_cs", 1},
+  {50, "cp1251", "cp1251_bin", 1},
+  {51, "cp1251", "cp1251_general_ci", 1},
+  {52, "cp1251", "cp1251_general_cs", 1},
+  {53, "macroman", "macroman_bin", 1},
+  {54, "utf16", "utf16_general_ci", 4},
+  {55, "utf16", "utf16_bin", 4},
+  {56, "utf16le", "utf16le_general_ci", 4},
+  {57, "cp1256", "cp1256_general_ci", 1},
+  {58, "cp1257", "cp1257_bin", 1},
+  {59, "cp1257", "cp1257_general_ci", 1},
+  {60, "utf32", "utf32_general_ci", 4},
+  {61, "utf32", "utf32_bin", 4},
+  {62, "utf16le", "utf16le_bin", 4},
+  {63, "binary", "binary", 1},
+  {64, "armscii8", "armscii8_bin", 1},
+  {65, "ascii", "ascii_bin", 1},
+  {66, "cp1250", "cp1250_bin", 1},
+  {67, "cp1256", "cp1256_bin", 1},
+  {68, "cp866", "cp866_bin", 1},
+  {69, "dec8", "dec8_bin", 1},
+  {70, "greek", "greek_bin", 1},
+  {71, "hebrew", "hebrew_bin", 1},
+  {72, "hp8", "hp8_bin", 1},
+  {73, "keybcs2", "keybcs2_bin", 1},
+  {74, "koi8r", "koi8r_bin", 1},
+  {75, "koi8u", "koi8u_bin", 1},
+  {76, "utf8", "utf8_tolower_ci", 3},
+  {77, "latin2", "latin2_bin", 1},
+  {78, "latin5", "latin5_bin", 1},
+  {79, "latin7", "latin7_bin", 1},
+  {80, "cp850", "cp850_bin", 1},
+  {81, "cp852", "cp852_bin", 1},
+  {82, "swe7", "swe7_bin", 1},
+  {83, "utf8", "utf8_bin", 3},
+  {84, "big5", "big5_bin", 2},
+  {85, "euckr", "euckr_bin", 2},
+  {86, "gb2312", "gb2312_bin", 2},
+  {87, "gbk", "gbk_bin", 2},
+  {88, "sjis", "sjis_bin", 2},
+  {89, "tis620", "tis620_bin", 1},
+  {90, "ucs2", "ucs2_bin", 2},
+  {91, "ujis", "ujis_bin", 3},
+  {92, "geostd8", "geostd8_general_ci", 1},
+  {93, "geostd8", "geostd8_bin", 1},
+  {94, "latin1", "latin1_spanish_ci", 1},
+  {95, "cp932", "cp932_japanese_ci", 2},
+  {96, "cp932", "cp932_bin", 2},
+  {97, "eucjpms", "eucjpms_japanese_ci", 3},
+  {98, "eucjpms", "eucjpms_bin", 3},
+  {99, "cp1250", "cp1250_polish_ci", 1},
+  {100, "NONE", "NONE", 0},
+  {101, "utf16", "utf16_unicode_ci", 4},
+  {102, "utf16", "utf16_icelandic_ci", 4},
+  {103, "utf16", "utf16_latvian_ci", 4},
+  {104, "utf16", "utf16_romanian_ci", 4},
+  {105, "utf16", "utf16_slovenian_ci", 4},
+  {106, "utf16", "utf16_polish_ci", 4},
+  {107, "utf16", "utf16_estonian_ci", 4},
+  {108, "utf16", "utf16_spanish_ci", 4},
+  {109, "utf16", "utf16_swedish_ci", 4},
+  {110, "utf16", "utf16_turkish_ci", 4},
+  {111, "utf16", "utf16_czech_ci", 4},
+  {112, "utf16", "utf16_danish_ci", 4},
+  {113, "utf16", "utf16_lithuanian_ci", 4},
+  {114, "utf16", "utf16_slovak_ci", 4},
+  {115, "utf16", "utf16_spanish2_ci", 4},
+  {116, "utf16", "utf16_roman_ci", 4},
+  {117, "utf16", "utf16_persian_ci", 4},
+  {118, "utf16", "utf16_esperanto_ci", 4},
+  {119, "utf16", "utf16_hungarian_ci", 4},
+  {120, "utf16", "utf16_sinhala_ci", 4},
+  {121, "utf16", "utf16_german2_ci", 4},
+  {122, "utf16", "utf16_croatian_ci", 4},
+  {123, "utf16", "utf16_unicode_520_ci", 4},
+  {124, "utf16", "utf16_vietnamese_ci", 4},
+  {125, "NONE", "NONE", 0},
+  {126, "NONE", "NONE", 0},
+  {127, "NONE", "NONE", 0},
+  {128, "ucs2", "ucs2_unicode_ci", 2},
+  {129, "ucs2", "ucs2_icelandic_ci", 2},
+  {130, "ucs2", "ucs2_latvian_ci", 2},
+  {131, "ucs2", "ucs2_romanian_ci", 2},
+  {132, "ucs2", "ucs2_slovenian_ci", 2},
+  {133, "ucs2", "ucs2_polish_ci", 2},
+  {134, "ucs2", "ucs2_estonian_ci", 2},
+  {135, "ucs2", "ucs2_spanish_ci", 2},
+  {136, "ucs2", "ucs2_swedish_ci", 2},
+  {137, "ucs2", "ucs2_turkish_ci", 2},
+  {138, "ucs2", "ucs2_czech_ci", 2},
+  {139, "ucs2", "ucs2_danish_ci", 2},
+  {140, "ucs2", "ucs2_lithuanian_ci", 2},
+  {141, "ucs2", "ucs2_slovak_ci", 2},
+  {142, "ucs2", "ucs2_spanish2_ci", 2},
+  {143, "ucs2", "ucs2_roman_ci", 2},
+  {144, "ucs2", "ucs2_persian_ci", 2},
+  {145, "ucs2", "ucs2_esperanto_ci", 2},
+  {146, "ucs2", "ucs2_hungarian_ci", 2},
+  {147, "ucs2", "ucs2_sinhala_ci", 2},
+  {148, "ucs2", "ucs2_german2_ci", 2},
+  {149, "ucs2", "ucs2_croatian_ci", 2},
+  {150, "ucs2", "ucs2_unicode_520_ci", 2},
+  {151, "ucs2", "ucs2_vietnamese_ci", 2},
+  {152, "NONE", "NONE", 0},
+  {153, "NONE", "NONE", 0},
+  {154, "NONE", "NONE", 0},
+  {155, "NONE", "NONE", 0},
+  {156, "NONE", "NONE", 0},
+  {157, "NONE", "NONE", 0},
+  {158, "NONE", "NONE", 0},
+  {159, "ucs2", "ucs2_general_mysql500_ci", 2},
+  {160, "utf32", "utf32_unicode_ci", 4},
+  {161, "utf32", "utf32_icelandic_ci", 4},
+  {162, "utf32", "utf32_latvian_ci", 4},
+  {163, "utf32", "utf32_romanian_ci", 4},
+  {164, "utf32", "utf32_slovenian_ci", 4},
+  {165, "utf32", "utf32_polish_ci", 4},
+  {166, "utf32", "utf32_estonian_ci", 4},
+  {167, "utf32", "utf32_spanish_ci", 4},
+  {168, "utf32", "utf32_swedish_ci", 4},
+  {169, "utf32", "utf32_turkish_ci", 4},
+  {170, "utf32", "utf32_czech_ci", 4},
+  {171, "utf32", "utf32_danish_ci", 4},
+  {172, "utf32", "utf32_lithuanian_ci", 4},
+  {173, "utf32", "utf32_slovak_ci", 4},
+  {174, "utf32", "utf32_spanish2_ci", 4},
+  {175, "utf32", "utf32_roman_ci", 4},
+  {176, "utf32", "utf32_persian_ci", 4},
+  {177, "utf32", "utf32_esperanto_ci", 4},
+  {178, "utf32", "utf32_hungarian_ci", 4},
+  {179, "utf32", "utf32_sinhala_ci", 4},
+  {180, "utf32", "utf32_german2_ci", 4},
+  {181, "utf32", "utf32_croatian_ci", 4},
+  {182, "utf32", "utf32_unicode_520_ci", 4},
+  {183, "utf32", "utf32_vietnamese_ci", 4},
+  {184, "NONE", "NONE", 0},
+  {185, "NONE", "NONE", 0},
+  {186, "NONE", "NONE", 0},
+  {187, "NONE", "NONE", 0},
+  {188, "NONE", "NONE", 0},
+  {189, "NONE", "NONE", 0},
+  {190, "NONE", "NONE", 0},
+  {191, "NONE", "NONE", 0},
+  {192, "utf8", "utf8_unicode_ci", 3},
+  {193, "utf8", "utf8_icelandic_ci", 3},
+  {194, "utf8", "utf8_latvian_ci", 3},
+  {195, "utf8", "utf8_romanian_ci", 3},
+  {196, "utf8", "utf8_slovenian_ci", 3},
+  {197, "utf8", "utf8_polish_ci", 3},
+  {198, "utf8", "utf8_estonian_ci", 3},
+  {199, "utf8", "utf8_spanish_ci", 3},
+  {200, "utf8", "utf8_swedish_ci", 3},
+  {201, "utf8", "utf8_turkish_ci", 3},
+  {202, "utf8", "utf8_czech_ci", 3},
+  {203, "utf8", "utf8_danish_ci", 3},
+  {204, "utf8", "utf8_lithuanian_ci", 3},
+  {205, "utf8", "utf8_slovak_ci", 3},
+  {206, "utf8", "utf8_spanish2_ci", 3},
+  {207, "utf8", "utf8_roman_ci", 3},
+  {208, "utf8", "utf8_persian_ci", 3},
+  {209, "utf8", "utf8_esperanto_ci", 3},
+  {210, "utf8", "utf8_hungarian_ci", 3},
+  {211, "utf8", "utf8_sinhala_ci", 3},
+  {212, "utf8", "utf8_german2_ci", 3},
+  {213, "utf8", "utf8_croatian_ci", 3},
+  {214, "utf8", "utf8_unicode_520_ci", 3},
+  {215, "utf8", "utf8_vietnamese_ci", 3},
+  {216, "NONE", "NONE", 0},
+  {217, "NONE", "NONE", 0},
+  {218, "NONE", "NONE", 0},
+  {219, "NONE", "NONE", 0},
+  {220, "NONE", "NONE", 0},
+  {221, "NONE", "NONE", 0},
+  {222, "NONE", "NONE", 0},
+  {223, "utf8", "utf8_general_mysql500_ci", 3},
+  {224, "utf8mb4", "utf8mb4_unicode_ci", 4},
+  {225, "utf8mb4", "utf8mb4_icelandic_ci", 4},
+  {226, "utf8mb4", "utf8mb4_latvian_ci", 4},
+  {227, "utf8mb4", "utf8mb4_romanian_ci", 4},
+  {228, "utf8mb4", "utf8mb4_slovenian_ci", 4},
+  {229, "utf8mb4", "utf8mb4_polish_ci", 4},
+  {230, "utf8mb4", "utf8mb4_estonian_ci", 4},
+  {231, "utf8mb4", "utf8mb4_spanish_ci", 4},
+  {232, "utf8mb4", "utf8mb4_swedish_ci", 4},
+  {233, "utf8mb4", "utf8mb4_turkish_ci", 4},
+  {234, "utf8mb4", "utf8mb4_czech_ci", 4},
+  {235, "utf8mb4", "utf8mb4_danish_ci", 4},
+  {236, "utf8mb4", "utf8mb4_lithuanian_ci", 4},
+  {237, "utf8mb4", "utf8mb4_slovak_ci", 4},
+  {238, "utf8mb4", "utf8mb4_spanish2_ci", 4},
+  {239, "utf8mb4", "utf8mb4_roman_ci", 4},
+  {240, "utf8mb4", "utf8mb4_persian_ci", 4},
+  {241, "utf8mb4", "utf8mb4_esperanto_ci", 4},
+  {242, "utf8mb4", "utf8mb4_hungarian_ci", 4},
+  {243, "utf8mb4", "utf8mb4_sinhala_ci", 4},
+  {244, "utf8mb4", "utf8mb4_german2_ci", 4},
+  {245, "utf8mb4", "utf8mb4_croatian_ci", 4},
+  {246, "utf8mb4", "utf8mb4_unicode_520_ci", 4},
+  {247, "utf8mb4", "utf8mb4_vietnamese_ci", 4},
+  {248, "gb18030", "gb18030_chinese_ci", 4},
+  {249, "gb18030", "gb18030_bin", 4},
+  {250, "gb18030", "gb18030_unicode_520_ci", 4},
+  {251, "NONE", "NONE", 0},
+  {252, "NONE", "NONE", 0},
+  {253, "NONE", "NONE", 0},
+  {254, "NONE", "NONE", 0},
+  {255, "utf8mb4", "utf8mb4_0900_ai_ci", 4},
+  {256, "utf8mb4", "utf8mb4_de_pb_0900_ai_ci", 4},
+  {257, "utf8mb4", "utf8mb4_is_0900_ai_ci", 4},
+  {258, "utf8mb4", "utf8mb4_lv_0900_ai_ci", 4},
+  {259, "utf8mb4", "utf8mb4_ro_0900_ai_ci", 4},
+  {260, "utf8mb4", "utf8mb4_sl_0900_ai_ci", 4},
+  {261, "utf8mb4", "utf8mb4_pl_0900_ai_ci", 4},
+  {262, "utf8mb4", "utf8mb4_et_0900_ai_ci", 4},
+  {263, "utf8mb4", "utf8mb4_es_0900_ai_ci", 4},
+  {264, "utf8mb4", "utf8mb4_sv_0900_ai_ci", 4},
+  {265, "utf8mb4", "utf8mb4_tr_0900_ai_ci", 4},
+  {266, "utf8mb4", "utf8mb4_cs_0900_ai_ci", 4},
+  {267, "utf8mb4", "utf8mb4_da_0900_ai_ci", 4},
+  {268, "utf8mb4", "utf8mb4_lt_0900_ai_ci", 4},
+  {269, "utf8mb4", "utf8mb4_sk_0900_ai_ci", 4},
+  {270, "utf8mb4", "utf8mb4_es_trad_0900_ai_ci", 4},
+  {271, "utf8mb4", "utf8mb4_la_0900_ai_ci", 4},
+  {272, "NONE", "NONE", 0},
+  {273, "utf8mb4", "utf8mb4_eo_0900_ai_ci", 4},
+  {274, "utf8mb4", "utf8mb4_hu_0900_ai_ci", 4},
+  {275, "utf8mb4", "utf8mb4_hr_0900_ai_ci", 4},
+  {276, "NONE", "NONE", 0},
+  {277, "utf8mb4", "utf8mb4_vi_0900_ai_ci", 4},
+  {278, "utf8mb4", "utf8mb4_0900_as_cs", 4},
+  {279, "utf8mb4", "utf8mb4_de_pb_0900_as_cs", 4},
+  {280, "utf8mb4", "utf8mb4_is_0900_as_cs", 4},
+  {281, "utf8mb4", "utf8mb4_lv_0900_as_cs", 4},
+  {282, "utf8mb4", "utf8mb4_ro_0900_as_cs", 4},
+  {283, "utf8mb4", "utf8mb4_sl_0900_as_cs", 4},
+  {284, "utf8mb4", "utf8mb4_pl_0900_as_cs", 4},
+  {285, "utf8mb4", "utf8mb4_et_0900_as_cs", 4},
+  {286, "utf8mb4", "utf8mb4_es_0900_as_cs", 4},
+  {287, "utf8mb4", "utf8mb4_sv_0900_as_cs", 4},
+  {288, "utf8mb4", "utf8mb4_tr_0900_as_cs", 4},
+  {289, "utf8mb4", "utf8mb4_cs_0900_as_cs", 4},
+  {290, "utf8mb4", "utf8mb4_da_0900_as_cs", 4},
+  {291, "utf8mb4", "utf8mb4_lt_0900_as_cs", 4},
+  {292, "utf8mb4", "utf8mb4_sk_0900_as_cs", 4},
+  {293, "utf8mb4", "utf8mb4_es_trad_0900_as_cs", 4},
+  {294, "utf8mb4", "utf8mb4_la_0900_as_cs", 4},
+  {295, "NONE", "NONE", 0},
+  {296, "utf8mb4", "utf8mb4_eo_0900_as_cs", 4},
+  {297, "utf8mb4", "utf8mb4_hu_0900_as_cs", 4},
+  {298, "utf8mb4", "utf8mb4_hr_0900_as_cs", 4},
+  {299, "NONE", "NONE", 0},
+  {300, "utf8mb4", "utf8mb4_vi_0900_as_cs", 4},
+  {301, "NONE", "NONE", 0},
+  {302, "NONE", "NONE", 0},
+  {303, "utf8mb4", "utf8mb4_ja_0900_as_cs", 4},
+  {304, "utf8mb4", "utf8mb4_ja_0900_as_cs_ks", 4},
+  {305, "utf8mb4", "utf8mb4_0900_as_ci", 4},
+  {306, "utf8mb4", "utf8mb4_ru_0900_ai_ci", 4},
+  {307, "utf8mb4", "utf8mb4_ru_0900_as_cs", 4},
+  {308, "utf8mb4", "utf8mb4_zh_0900_as_cs", 4},
+  {309, "utf8mb4", "utf8mb4_0900_bin", 4},
+};
+
+
+unsigned int get_charset_maxlen(unsigned int num)
+{
+  if (num < 310)
+    return charset_collation_info[num].maxlen;
+
+  return 0;
+}
 
 /********************************
 This charset mapping function is cut out from server repo: sql_common/client.c
@@ -1269,47 +1594,14 @@ char *myodbc_int10_to_str(long int val, char *dst, int radix) {
 }
 
 
-bool myodbc_init_dynamic_string(DYNAMIC_STRING *str, const char *init_str,
-                         size_t init_alloc, size_t alloc_increment) {
-  size_t length;
-  DBUG_TRACE;
-
-  if (!alloc_increment) alloc_increment = 128;
-  length = 1;
-  if (init_str && (length = strlen(init_str) + 1) < init_alloc)
-    init_alloc =
-        ((length + alloc_increment - 1) / alloc_increment) * alloc_increment;
-  if (!init_alloc) init_alloc = alloc_increment;
-
-  if (!(str->str = (char *)my_malloc(PSI_NOT_INSTRUMENTED, init_alloc,
-                                     MYF(MY_WME))))
-    return true;
-  str->length = length - 1;
-  if (init_str) memcpy(str->str, init_str, length);
-  str->max_length = init_alloc;
-  str->alloc_increment = alloc_increment;
+bool myodbc_append_mem_std(std::string &str, const char *append, size_t length)
+{
+  str.append(append, length);
   return false;
 }
 
-bool myodbc_append_mem(DYNAMIC_STRING *str, const char *append, size_t length) {
-  char *new_ptr;
-  if (str->length + length >= str->max_length) {
-    size_t new_length =
-        (str->length + length + str->alloc_increment) / str->alloc_increment;
-    new_length *= str->alloc_increment;
-    if (!(new_ptr = (char *)my_realloc(PSI_NOT_INSTRUMENTED, str->str,
-                                       new_length, MYF(MY_WME))))
-      return true;
-    str->str = new_ptr;
-    str->max_length = new_length;
-  }
-  if (length > 0) memcpy(str->str + str->length, append, length);
-  str->length += length;
-  str->str[str->length] = 0; /* Safety for C programs */
-  return false;
-}
 
-bool myodbc_append_os_quoted(DYNAMIC_STRING *str, const char *append, ...) {
+bool myodbc_append_os_quoted_std(std::string &str, const char *append, ...) {
 #ifdef _WIN32
   const char *quote_str = "\"";
   const uint quote_len = 1;
@@ -1319,8 +1611,8 @@ bool myodbc_append_os_quoted(DYNAMIC_STRING *str, const char *append, ...) {
 #endif /* _WIN32 */
   bool ret = true;
   va_list dirty_text;
-
-  ret &= myodbc_append_mem(str, quote_str, quote_len); /* Leading quote */
+  str.reserve(str.length() + 128);
+  str.append(quote_str, quote_len); /* Leading quote */
   va_start(dirty_text, append);
   while (append != NullS) {
     const char *cur_pos = append;
@@ -1328,40 +1620,20 @@ bool myodbc_append_os_quoted(DYNAMIC_STRING *str, const char *append, ...) {
 
     /* Search for quote in each string and replace with escaped quote */
     while (*(next_pos = strcend(cur_pos, quote_str[0])) != '\0') {
-      ret &= myodbc_append_mem(str, cur_pos, (uint)(next_pos - cur_pos));
-      ret &= myodbc_append_mem(str, "\\", 1);
-      ret &= myodbc_append_mem(str, quote_str, quote_len);
+      str.append(cur_pos, (uint)(next_pos - cur_pos)).
+          append("\\", 1).append(quote_str, quote_len);
       cur_pos = next_pos + 1;
     }
-    ret &= myodbc_append_mem(str, cur_pos, (uint)(next_pos - cur_pos));
+    str.append(cur_pos, (uint)(next_pos - cur_pos));
     append = va_arg(dirty_text, char *);
   }
   va_end(dirty_text);
-  ret &= myodbc_append_mem(str, quote_str, quote_len); /* Trailing quote */
+  str.append(quote_str, quote_len); /* Trailing quote */
 
-  return ret;
-}
-
-void myodbc_dynstr_free(DYNAMIC_STRING *str) {
-  my_free(str->str);
-  str->str = NULL;
-}
-
-bool myodbc_dynstr_realloc(DYNAMIC_STRING *str, size_t additional_size) {
-  DBUG_TRACE;
-
-  if (!additional_size) return false;
-  if (str->length + additional_size > str->max_length) {
-    str->max_length =
-        ((str->length + additional_size + str->alloc_increment - 1) /
-         str->alloc_increment) *
-        str->alloc_increment;
-    if (!(str->str = (char *)my_realloc(PSI_NOT_INSTRUMENTED, str->str,
-                                        str->max_length, MYF(MY_WME))))
-      return true;
-  }
   return false;
 }
 
 
+
+
 #endif
\ No newline at end of file
